<?php

namespace EventPortal\Tests\Feature\Admin\EventSignIn;

use Carbon\Carbon;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class EventSignInIndexTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test */
    public function can_view_index(): void
    {
        Carbon::setTestNow(Carbon::parse('20 October 2020'));
        $event = factory(Event::class)->state('snapshot')->create();
        Pathway::generate($event, Pathway::DEFAULT, 'The default pathway');
        $delegate = factory(Delegate::class)->state('snapshot')->create();
        $event->delegates()->attach($delegate, [
            'pathway_id' => Pathway::defaultForEvent($event)->first()->id,
            'status' => 'invited',
        ]);

        $this->assertMatchesJsonSnapshot(
            $this
                ->actingAsSuperAdmin()
                ->get(route('admin.event.sign-in.index', $event))
                ->props()
        );
    }
}
