<?php

namespace EventPortal\Tests\Unit\Delegate\Handlers;

use EventPortal\Domain\Delegate\Handlers\ContactEvent;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\Util\Notification\SystemNotification;
use Illuminate\Support\Facades\Notification;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class ContactEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function delegate_can_contact_event()
    {
        Notification::fake();

        $event = factory(Event::class)->create(['email' => 'hello@example.com']);

        $input = [
            'first_name' => 'Ash',
            'last_name' => 'Packwood',
            'email' => 'ash@example.com',
            'subject' => 'The Subject',
            'message' => 'Hello there!',
        ];

        $payload = Payload::make()->addToInput($input)->withModel($event);

        app(Pipeline::class)
            ->send($payload)
            ->through([new ContactEvent])
            ->thenReturn();

        Notification::assertSentTo(
            [$event],
            SystemNotification::class,
            function (SystemNotification $notification) use ($event) {
                return $notification->subject === 'The Subject';
            }
        );
    }
}
