<?php

namespace EventPortal\Tests\Unit\Event\Actions;

use EventPortal\Domain\Event\Actions\TransitionEvent;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use SM\SMException;

class TransitionEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_transition()
    {
        $event = factory(Event::class)->state('draft')->create();

        (new TransitionEvent())->execute($event, 'publish');

        $this->assertEquals('published', $event->status);

        (new TransitionEvent())->execute($event, 'complete');

        $this->assertEquals('post', $event->status);
    }

    /** @test **/
    public function cannot_transition_to_nonexistent_state()
    {
        $this->expectException(SMException::class);

        $event = factory(Event::class)->state('draft')->create();

        (new TransitionEvent())->execute($event, 'non-existent-state');

        $this->assertEquals('draft', $event->status);
    }

    /** @test **/
    public function cannot_transition_to_state_that_is_not_allowed()
    {
        $this->expectException(SMException::class);

        $event = factory(Event::class)->state('draft')->create();

        (new TransitionEvent())->execute($event, 'complete');

        $this->assertEquals('draft', $event->status);
    }
}
